@@ -138,7 +138,7 @@ class BingSpider():
         # logger.debug(kwargs)
         page_num = kwargs.get("page_num") if kwargs.get("page_num") else 0
         keyword = kwargs.get("keyword") if kwargs.get("keyword") else "None"
-        item_num = kwargs.get("item_num") if kwargs.get("item_num") else None # 默认如果没有获取到则None，None就按全部返回
+        # item_num = kwargs.get("item_num") if kwargs.get("item_num") else None # 默认如果没有获取到则None，None就按全部返回
         item_list = []
         for i, item in enumerate(items):
             link = item.xpath("div[@class='b_title']/a/@href")
@@ -157,7 +157,7 @@ class BingSpider():
             rank = i + 1
 
             try:
-                item = SearchItem(title=title, url=link, content=content, search_keyword=keyword, time=date, source = "", page_num=page_num, page_rank=rank)
+                item = SearchItem(title=title, url=link, content=content, search_keyword=keyword, date=date, source = "", page_num=page_num, page_rank=rank)
                 item_list.append(item.__dict__)
             except Exception as e:
                 logger.error(f"[item parse error]: {e}")
@@ -166,12 +166,12 @@ class BingSpider():
                 self.item_queue.put(item)
                 logger.debug(item.__dict__)
         
-        if item_num:
-            logger.debug(f"根据item num返回{item_num}个")
-            return item_list[:item_num]
-        else:
-            logger.debug(f"返回全部")
-            return item_list
+        # if item_num:
+        #     logger.debug(f"根据item num返回{item_num}个")
+        #     return item_list[:item_num]
+        # else:
+            # logger.debug(f"返回全部, 共计{len(item_list)}个")
+        return item_list
 
 
     def saver(self, item: SearchItem):
@@ -207,27 +207,46 @@ class BingSpider():
         @item_num: 返回item数，写1就拿一个。比如我是0，10页，每页100个，但是item写1，就只返回一个。
         @kwargs: 其他参数，如代理包括proxies, auth
         """
+        all_item_list = []
         if kwargs.get('proxies'): # 启用代理
             proxies = kwargs.get("proxies") if kwargs.get("proxies") else None
             auth = kwargs.get("auth") if kwargs.get("auth") else None
             self.headers.update({
                 "Proxy-Authorization": auth,
             })
-            response = self.single_request(keyword, start_page, **kwargs)
+            for i in range(start_page, end_page):
+                response = self.single_request(keyword, i, proxies=proxies)
+                if self.validator(response):
+                    item_list = self.parser(response, **{"keyword": keyword, "page_num": i+1, "item_num": item_num})
+                    all_item_list += item_list
+                    # return all_item_list
+                else:
+                    logger.error("response is invalid")
+                    continue
         else:
-            response = self.single_request(keyword, start_page)
+            for i in range(start_page, end_page):
+                response = self.single_request(keyword, i)
+                if self.validator(response):
+                    item_list = self.parser(response, **{"keyword": keyword, "page_num": i+1, "item_num": item_num})
+                    all_item_list += item_list
+                    # return all_item_list
+                else:
+                    logger.error("response is invalid")
+                    continue
         
         # 处理
-        item_list = self.parser(response, **{"keyword": keyword, "page_num": start_page, "item_num": item_num})
+        # item_list = self.parser(response, **{"keyword": keyword, "page_num": start_page, "item_num": item_num})
         if item_num:
-            return item_list[item_num]
+            logger.info(f"根据item num返回{item_num}个")
+            return all_item_list[item_num:]
         else:
-            return item_list
+            logger.info(f"返回全部, 共计{len(all_item_list)}个")
+            return all_item_list
 
 if __name__ == "__main__":
     print("a")
     spider = BingSpider()
-    res = spider.search("自称家里有50辆宾利女车主发声")
+    res = spider.search("自称家里有50辆宾利女车主发声",0, 3)
     print(res)
     # spider.start_request(["深圳市黑石互娱科技有限公司 企查查"], 0, 1)
     # kwargs = {
